@@ -14,7 +14,7 @@ import warnings
 from numba.core.errors import NumbaWarning
 warnings.filterwarnings("ignore", category=NumbaWarning)
 
-__version__ = "0.8.1"
+__version__ = "0.8.3"
 
 
 class SAMGUI(object):
@@ -95,6 +95,15 @@ class SAMGUI(object):
         self.SamPlot = widgets.HBox(
             items, layout=Layout(width="auto", height=str(height) + "px")
         )
+
+        x = self.stab.children[self.stab.selected_index]
+        f = x.layout.xaxis.range
+        x.layout.xaxis.range=(-1,1)
+        x.layout.xaxis.range=f        
+
+        f = x.layout.yaxis.range
+        x.layout.yaxis.range=(-1,1)
+        x.layout.yaxis.range=f
         
     def __setstate__(self,d):       
         self.__init__(sam = d['sams'],title=d['titles'],
@@ -1675,6 +1684,17 @@ class SAMGUI(object):
                 i, self.names[i] + " (" + str(self.stab.selected_index) + ")"
             )
 
+        x = self.stab.children[self.stab.selected_index]
+        f = x.layout.xaxis.range
+        x.layout.xaxis.range=(-1,1)
+        x.layout.xaxis.range=f        
+
+        f = x.layout.yaxis.range
+        x.layout.yaxis.range=(-1,1)
+        x.layout.yaxis.range=f
+
+            
+
     def display_var_annotation(self, event):
         self.GENE_KEY = self.cs_dict["DVM"].value
         self.log('Setting the var annotations to be from key {}'.format(self.GENE_KEY))
